django-emailtools
-----------------

.. image:: https://travis-ci.org/fusionbox/django-emailtools.png
   :target: http://travis-ci.org/fusionbox/django-emailtools
   :alt: Build Status

Django Email Tools is a suite of tools meant to assist in sending emails from
your Django app.


Installation
============

1.  Install the package::

    $ pip install django-emailtools

2.  Add ``emailtools`` to your ``INSTALLED_APPS``.
